==> lack-1.0.tar.gz: lack-1.0/lack-init.ml <==
(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Foobar is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Printf
open Utils
open Init

let usage = sprintf "Lack %s, a package manager for all it lacks on your computer\nRun this program to initializate the lack environment" Version.version

let _ =
  let is_prepare = ref false in
  let is_update = ref false in
  let base = ref (Defaults.give "base") in
  let arguments = (Arg.align [
                     "--prepare", Arg.Set is_prepare , (" Create the lack directory (defaults to "^ !base ^")");
                     "--update" , Arg.Set is_update  , (" Update lack envirronement using $LACK");
                     "--prefix" , Arg.Set_string base, (" Path to lack files (defaults to "^ !base ^")");
                   ])
  in
    Arg.parse arguments (fun x -> ()) usage;
    if !is_prepare then
      prepare base
    else
      if !is_update then
        ignore (update (Sys.getenv "LACK"))
      else
        expose !base

==> lack-1.1.tar.gz: lack-1.1/lack-init.ml <==
(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Lack is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Lack.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Printf
open Utils
open Init

let usage = sprintf "Lack %s, a package manager for all it lacks on your computer\nRun this program to initializate the lack environment" Version.version

let _ =
  let is_prepare = ref false in
  let is_update = ref false in
  let base = ref (Defaults.give "base") in
  let arguments = (Arg.align [
                     "--prepare", Arg.Set is_prepare , (" Create the lack directory (defaults to "^ !base ^")");
                     "--update" , Arg.Set is_update  , (" Update lack envirronement using $LACK");
                     "--prefix" , Arg.Set_string base, (" Path to lack files (defaults to "^ !base ^")");
                   ])
  in
    Arg.parse arguments (fun x -> ()) usage;
    if !is_prepare then
      prepare base
    else
      if !is_update then
        ignore (update (Sys.getenv "LACK"))
      else
        expose !base
